==> igloo_0_1_3.zip: igloo_0_1_3/igloo/config/config_acs.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2005 (info@barnraiser.org)



// RESOURCES --------------------------------------------------------------------
// A list of resources available within the build
$c_acs['arr_acs']['resource']['administration'] = 	"1";
$c_acs['arr_acs']['resource']['network'] = 			"2";
$c_acs['arr_acs']['resource']['rsp'] = 				"3";
$c_acs['arr_acs']['resource']['shoutbox'] = 		"4";
$c_acs['arr_acs']['resource']['library'] = 			"5";
$c_acs['arr_acs']['resource']['forum'] = 			"6";
$c_acs['arr_acs']['resource']['files'] = 			"7";
$c_acs['arr_acs']['resource']['schedule'] = 		"8";
$c_acs['arr_acs']['resource']['poll'] = 			"9";
$c_acs['arr_acs']['resource']['blog'] = 			"10";
$c_acs['arr_acs']['resource']['channels'] = 		"11";



// RESOURCE PRIVILEGE CONFIGURATION
// privileges are attached to resources
// $c_acs['resource_privilege'][1] - '1' refers to the id of the language
// array ( $acs['arr_resource'][1])
// we store an array of privilege_id's which refer to the id of the privilege
// array ( $acs['arr_privilege'][1])
//
$c_acs['resource_privilege'][1] = 			array(1,2,3,4,5); 			//administration
$c_acs['resource_privilege'][2] = 			array(6,7,8,9,18, 19); 		//network
$c_acs['resource_privilege'][3] = 			array(15,16,17); 			//publishing
$c_acs['resource_privilege'][4] = 			array(10,11); 				//shoutbox
$c_acs['resource_privilege'][5] = 			array(10,11,12,18); 		//library
$c_acs['resource_privilege'][6] = 			array(10,11,12,13,14,18,20); //forum
$c_acs['resource_privilege'][7] = 			array(10,11); 				//files
$c_acs['resource_privilege'][8] = 			array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][9] = 			array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][10] = 			array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][11] = 			array(10,11); 				//channel

// PRIVILEGES --------------------------------------------------------------------
// A list of privileges available within the build
$c_acs['arr_acs']['privilege']['allow_membership'] = 		"1";
$c_acs['arr_acs']['privilege']['allow_newsletter'] = 		"2";
$c_acs['arr_acs']['privilege']['allow_acs'] = 				"3";
$c_acs['arr_acs']['privilege']['allow_rsp'] = 				"4";
$c_acs['arr_acs']['privilege']['allow_abuse_reports'] = 	"5";
$c_acs['arr_acs']['privilege']['allow_directory'] = 		"6";
$c_acs['arr_acs']['privilege']['allow_network'] = 			"7";
$c_acs['arr_acs']['privilege']['allow_network_int'] = 		"8";
$c_acs['arr_acs']['privilege']['allow_network_ext'] = 		"9";
$c_acs['arr_acs']['privilege']['allow_access'] = 			"10";
$c_acs['arr_acs']['privilege']['add_item'] = 				"11";
$c_acs['arr_acs']['privilege']['allow_comment'] =	 		"12";
$c_acs['arr_acs']['privilege']['allow_locking'] = 			"13";
$c_acs['arr_acs']['privilege']['allow_hidden'] = 			"14";
$c_acs['arr_acs']['privilege']['allow_rsp_network'] = 		"15";
$c_acs['arr_acs']['privilege']['allow_rsp_node'] = 			"16";
$c_acs['arr_acs']['privilege']['allow_rsp_public'] = 		"17";
$c_acs['arr_acs']['privilege']['allow_tagging'] = 			"18";
$c_acs['arr_acs']['privilege']['allow_profile'] = 			"19";
$c_acs['arr_acs']['privilege']['allow_topic_edit'] = 		"20";


// DEFAULTS --------------------------------------------------------------------
//what is the default role_id for a user at registration
$c_acs['arr_acs']['user_join_role_default'] = 				"3";


// END OF CONFIGURATION FILE ---------------------------------------------

?>

==> igloo_0_1_5.zip: igloo_0_1_5/igloo/config/config_acs.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2005 (info@barnraiser.org)



// RESOURCES --------------------------------------------------------------------
// A list of resources available within the build
$c_acs['arr_acs']['resource']['administration'] = 	"1";
$c_acs['arr_acs']['resource']['network'] = 			"2";
$c_acs['arr_acs']['resource']['rsp'] = 				"3";
$c_acs['arr_acs']['resource']['shoutbox'] = 		"4";
$c_acs['arr_acs']['resource']['library'] = 			"5";
$c_acs['arr_acs']['resource']['forum'] = 			"6";
$c_acs['arr_acs']['resource']['files'] = 			"7";
$c_acs['arr_acs']['resource']['schedule'] = 		"8";
$c_acs['arr_acs']['resource']['poll'] = 			"9";
$c_acs['arr_acs']['resource']['blog'] = 			"10";
$c_acs['arr_acs']['resource']['channels'] = 		"11";
$c_acs['arr_acs']['resource']['tagging'] = 			"12";



// RESOURCE PRIVILEGE CONFIGURATION
// privileges are attached to resources
// $c_acs['resource_privilege'][1] - '1' refers to the id of the language
// array ( $acs['arr_resource'][1])
// we store an array of privilege_id's which refer to the id of the privilege
// array ( $acs['arr_privilege'][1])
//
$c_acs['resource_privilege'][1] = 			array(1,2,3,4,5); 			//administration
$c_acs['resource_privilege'][2] = 			array(6,7,8,9,18, 19); 		//network
$c_acs['resource_privilege'][3] = 			array(15,16,17); 			//publishing
$c_acs['resource_privilege'][4] = 			array(10,11); 				//shoutbox
$c_acs['resource_privilege'][5] = 			array(10,11,12,18,22); 		//library
$c_acs['resource_privilege'][6] = 			array(10,11,12,13,14,18,20); //forum
$c_acs['resource_privilege'][7] = 			array(10,11); 				//files
$c_acs['resource_privilege'][8] = 			array(10,11,12,18); 		//schedule
$c_acs['resource_privilege'][9] = 			array(10,11,12,18); 		//poll
$c_acs['resource_privilege'][10] = 			array(10,11,12,18); 		//blog
$c_acs['resource_privilege'][11] = 			array(10,11); 				//channel
$c_acs['resource_privilege'][12] = 			array(10,21); 				//tagging


// PRIVILEGES --------------------------------------------------------------------
// A list of privileges available within the build
$c_acs['arr_acs']['privilege']['allow_membership'] = 		"1";
$c_acs['arr_acs']['privilege']['allow_newsletter'] = 		"2";
$c_acs['arr_acs']['privilege']['allow_acs'] = 				"3";
$c_acs['arr_acs']['privilege']['allow_rsp'] = 				"4";
$c_acs['arr_acs']['privilege']['allow_abuse_reports'] = 	"5";
$c_acs['arr_acs']['privilege']['allow_directory'] = 		"6";
$c_acs['arr_acs']['privilege']['allow_network'] = 			"7";
$c_acs['arr_acs']['privilege']['allow_network_int'] = 		"8";
$c_acs['arr_acs']['privilege']['allow_network_ext'] = 		"9";
$c_acs['arr_acs']['privilege']['allow_access'] = 			"10";
$c_acs['arr_acs']['privilege']['add_item'] = 				"11";
$c_acs['arr_acs']['privilege']['allow_comment'] =	 		"12";
$c_acs['arr_acs']['privilege']['allow_locking'] = 			"13";
$c_acs['arr_acs']['privilege']['allow_hidden'] = 			"14";
$c_acs['arr_acs']['privilege']['allow_rsp_network'] = 		"15";
$c_acs['arr_acs']['privilege']['allow_rsp_node'] = 			"16";
$c_acs['arr_acs']['privilege']['allow_rsp_public'] = 		"17";
$c_acs['arr_acs']['privilege']['allow_tagging'] = 			"18";
$c_acs['arr_acs']['privilege']['allow_profile'] = 			"19";
$c_acs['arr_acs']['privilege']['allow_topic_edit'] = 		"20";
$c_acs['arr_acs']['privilege']['allow_sch_tag_mgmt'] = 		"21";
$c_acs['arr_acs']['privilege']['allow_lib_default'] = 		"22";


// DEFAULTS --------------------------------------------------------------------
//what is the default role_id for a user at registration
$c_acs['arr_acs']['user_join_role_default'] = 				"3";


// END OF CONFIGURATION FILE ---------------------------------------------

?>
